@@ -419,7 +419,7 @@ void chum_change_to_song(const char *song_name){
   sample1 = jammo_sample_new_from_file(filename);
   jammo_editing_track_add_sample(backing_track, sample1, 0);
 
-  recording_track = jammo_recording_track_new_with_pitch_detect(RECORDING_FILENAME);
+  recording_track = jammo_recording_track_new(RECORDING_FILENAME);
   jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track));
 
   state_of_chum=SCREEN_SONG_RECORDING;
