@@ -9,7 +9,8 @@
  */
 
 #include "jammo-chum.h"
+#include <tangle.h>
 
 void jammo_chum_init(int* argc, char** argv[]) {
-	clutter_init(argc, argv);
+	tangle_init(argc, argv);
 }
