@@ -131,9 +131,14 @@ ClutterActor* config_get_configured_actor (const gchar *scriptname, gchar* actor
 ClutterActor* config_respawn_loop_actor (const gchar *theme_folder, gchar* actor_name) {
 		gchar *buffer;
 		ClutterActor* actor;
-		
-		buffer=g_strdup_printf("%s/%s/config.json", "/tmp/jammo",theme_folder);
-		ClutterScript* temp_script;	
+		//FIXME respawnig actor consumes large amounts of memory
+		if (strcmp(theme_folder, "sequencer") == 0) { //needed for sequencer_loop
+			buffer=g_strdup_printf("%s/config.json", SEQUENCER_DIR);
+		} else {
+			buffer=g_strdup_printf("%s/%s/config.json", "/tmp/jammo",theme_folder);
+		}
+
+		ClutterScript* temp_script;
 		if(!(temp_script = config_return_script(buffer)))
 			{
 			fprintf(stderr, "get_objects_for_theme:Error: Could not find config file.\n");
